You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@maven.apache.org by rf...@apache.org on 2019/12/18 22:15:29 UTC

[maven-integration-testing] branch MNG-6065 created (now e0f738f)

This is an automated email from the ASF dual-hosted git repository.

rfscholte pushed a change to branch MNG-6065
in repository https://gitbox.apache.org/repos/asf/maven-integration-testing.git.


      at e0f738f  Log fail-level option. Submitted by: Martin Kanters.

This branch includes the following new commits:

     new 900b1fa  Log fail-level option. Submitted by: Martin Kanters.
     new e0f738f  Log fail-level option. Submitted by: Martin Kanters.

The 2 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.



[maven-integration-testing] 02/02: Log fail-level option. Submitted by: Martin Kanters.

Posted by rf...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

rfscholte pushed a commit to branch MNG-6065
in repository https://gitbox.apache.org/repos/asf/maven-integration-testing.git

commit e0f738f7bb3ffcf78a916951fe32bf4e6124cb9e
Author: Martin Kanters <mk...@gmail.com>
AuthorDate: Tue Dec 17 22:11:16 2019 +0100

    Log fail-level option. Submitted by: Martin Kanters.
    
    Aligned the integration tests to the review comments on the --fail-on-severity flag, and updated the Maven version to the current one.
---
 .../org/apache/maven/it/IntegrationTestSuite.java    |  2 +-
 ...st.java => MavenITmng6065FailOnSeverityTest.java} | 20 +++++++++++---------
 .../pom.xml                                          |  2 +-
 3 files changed, 13 insertions(+), 11 deletions(-)

diff --git a/core-it-suite/src/test/java/org/apache/maven/it/IntegrationTestSuite.java b/core-it-suite/src/test/java/org/apache/maven/it/IntegrationTestSuite.java
index c1dfb49..10951b6 100644
--- a/core-it-suite/src/test/java/org/apache/maven/it/IntegrationTestSuite.java
+++ b/core-it-suite/src/test/java/org/apache/maven/it/IntegrationTestSuite.java
@@ -119,7 +119,7 @@ public class IntegrationTestSuite
         suite.addTestSuite( MavenITmng6223FindBasedir.class );
         suite.addTestSuite( MavenITmng6189SiteReportPluginsWarningTest.class );
         suite.addTestSuite( MavenITmng6127PluginExecutionConfigurationInterferenceTest.class );
-        suite.addTestSuite( MavenITmng6065LogFailLevelTest.class );
+        suite.addTestSuite( MavenITmng6065FailOnSeverityTest.class );
         suite.addTestSuite( MavenITmng6057CheckReactorOrderTest.class );
         suite.addTestSuite( MavenITmng5895CIFriendlyUsageWithPropertyTest.class );
         suite.addTestSuite( MavenITmng6090CIFriendlyTest.class );
diff --git a/core-it-suite/src/test/resources/mng-6065-log-fail-level/pom.xml b/core-it-suite/src/test/resources/mng-6065-fail-on-severity/pom.xml
similarity index 95%
rename from core-it-suite/src/test/resources/mng-6065-log-fail-level/pom.xml
rename to core-it-suite/src/test/resources/mng-6065-fail-on-severity/pom.xml
index 9e6300f..d08153d 100644
--- a/core-it-suite/src/test/resources/mng-6065-log-fail-level/pom.xml
+++ b/core-it-suite/src/test/resources/mng-6065-fail-on-severity/pom.xml
@@ -29,7 +29,7 @@ under the License.
 
   <name>Maven Integration Test :: MNG-6065</name>
   <description>
-    An integration test to verify that builds fail when logs occur above or equal to the --fail-level cli property.
+    An integration test to verify that builds fail when logs occur above or equal to the --fail-on-severity cli property.
     An empty project like this will already log warnings about the platform encoding and the empty jar.
   </description>
 </project>


[maven-integration-testing] 01/02: Log fail-level option. Submitted by: Martin Kanters.

Posted by rf...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

rfscholte pushed a commit to branch MNG-6065
in repository https://gitbox.apache.org/repos/asf/maven-integration-testing.git

commit 900b1fa637bcd5306bb51fee66204ccfdeae2481
Author: Martin Kanters <mk...@gmail.com>
AuthorDate: Thu Oct 3 21:12:43 2019 +0200

    Log fail-level option. Submitted by: Martin Kanters.
    
    Testing that a build with logs of warning level will fail when --fail-level=WARN and that it will not fail when --fail-level=ERROR.
---
 .../org/apache/maven/it/IntegrationTestSuite.java  |  1 +
 .../maven/it/MavenITmng6065LogFailLevelTest.java   | 80 ++++++++++++++++++++++
 .../test/resources/mng-6065-log-fail-level/pom.xml | 35 ++++++++++
 3 files changed, 116 insertions(+)

diff --git a/core-it-suite/src/test/java/org/apache/maven/it/IntegrationTestSuite.java b/core-it-suite/src/test/java/org/apache/maven/it/IntegrationTestSuite.java
index 6d61985..c1dfb49 100644
--- a/core-it-suite/src/test/java/org/apache/maven/it/IntegrationTestSuite.java
+++ b/core-it-suite/src/test/java/org/apache/maven/it/IntegrationTestSuite.java
@@ -119,6 +119,7 @@ public class IntegrationTestSuite
         suite.addTestSuite( MavenITmng6223FindBasedir.class );
         suite.addTestSuite( MavenITmng6189SiteReportPluginsWarningTest.class );
         suite.addTestSuite( MavenITmng6127PluginExecutionConfigurationInterferenceTest.class );
+        suite.addTestSuite( MavenITmng6065LogFailLevelTest.class );
         suite.addTestSuite( MavenITmng6057CheckReactorOrderTest.class );
         suite.addTestSuite( MavenITmng5895CIFriendlyUsageWithPropertyTest.class );
         suite.addTestSuite( MavenITmng6090CIFriendlyTest.class );
diff --git a/core-it-suite/src/test/java/org/apache/maven/it/MavenITmng6065LogFailLevelTest.java b/core-it-suite/src/test/java/org/apache/maven/it/MavenITmng6065LogFailLevelTest.java
new file mode 100644
index 0000000..e9b0eb9
--- /dev/null
+++ b/core-it-suite/src/test/java/org/apache/maven/it/MavenITmng6065LogFailLevelTest.java
@@ -0,0 +1,80 @@
+package org.apache.maven.it;
+
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
+import org.apache.maven.it.util.ResourceExtractor;
+
+import java.io.File;
+
+/**
+ * An integration test to verify that builds fail when logs occur
+ * above or equal to the --fail-level cli property.
+ *
+ * <a href="https://issues.apache.org/jira/browse/MNG-6065">MNG-6065</a>.
+ *
+ */
+public class MavenITmng6065LogFailLevelTest
+    extends AbstractMavenIntegrationTestCase
+{
+
+    public MavenITmng6065LogFailLevelTest()
+    {
+        super( "[3.6.3-SNAPSHOT,)" );
+    }
+
+    public void testItShouldFailOnWarnLogMessages()
+        throws Exception
+    {
+        File testDir = ResourceExtractor.simpleExtractResources( getClass(), "/mng-6065-log-fail-level" );
+
+        Verifier verifier = newVerifier( testDir.getAbsolutePath(), false );
+        verifier.addCliOption( "--fail-level" );
+        verifier.addCliOption( "WARN" );
+
+        boolean failed = false;
+
+        try
+        {
+            verifier.executeGoal( "compile" );
+        }
+        catch ( VerificationException e )
+        {
+            failed = true;
+            verifier.verifyTextInLog( "Enabled to break the build on log level WARN." );
+            verifier.verifyTextInLog( "Build failed due to log statements with a higher severity than allowed." );
+        }
+
+        assertTrue( "Build should have failed", failed );
+    }
+
+    public void testItShouldSucceedOnWarnLogMessagesWhenFailLevelIsError()
+            throws Exception
+    {
+        File testDir = ResourceExtractor.simpleExtractResources( getClass(), "/mng-6065-log-fail-level" );
+
+        Verifier verifier = newVerifier( testDir.getAbsolutePath(), false );
+        verifier.addCliOption( "--fail-level" );
+        verifier.addCliOption( "ERROR" );
+
+        verifier.executeGoal( "compile" );
+
+        verifier.verifyTextInLog( "Enabled to break the build on log level ERROR." );
+    }
+}
diff --git a/core-it-suite/src/test/resources/mng-6065-log-fail-level/pom.xml b/core-it-suite/src/test/resources/mng-6065-log-fail-level/pom.xml
new file mode 100644
index 0000000..9e6300f
--- /dev/null
+++ b/core-it-suite/src/test/resources/mng-6065-log-fail-level/pom.xml
@@ -0,0 +1,35 @@
+<?xml version="1.0" encoding="UTF-8"?>
+
+<!--
+Licensed to the Apache Software Foundation (ASF) under one
+or more contributor license agreements.  See the NOTICE file
+distributed with this work for additional information
+regarding copyright ownership.  The ASF licenses this file
+to you under the Apache License, Version 2.0 (the
+"License"); you may not use this file except in compliance
+with the License.  You may obtain a copy of the License at
+
+  http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing,
+software distributed under the License is distributed on an
+"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+KIND, either express or implied.  See the License for the
+specific language governing permissions and limitations
+under the License.
+-->
+
+<project>
+  <modelVersion>4.0.0</modelVersion>
+
+  <groupId>org.apache.maven.its.mng6065</groupId>
+  <artifactId>test</artifactId>
+  <version>0.1</version>
+  <packaging>jar</packaging>
+
+  <name>Maven Integration Test :: MNG-6065</name>
+  <description>
+    An integration test to verify that builds fail when logs occur above or equal to the --fail-level cli property.
+    An empty project like this will already log warnings about the platform encoding and the empty jar.
+  </description>
+</project>
diff --git a/core-it-suite/src/test/java/org/apache/maven/it/MavenITmng6065LogFailLevelTest.java b/core-it-suite/src/test/java/org/apache/maven/it/MavenITmng6065FailOnSeverityTest.java
similarity index 82%
rename from core-it-suite/src/test/java/org/apache/maven/it/MavenITmng6065LogFailLevelTest.java
rename to core-it-suite/src/test/java/org/apache/maven/it/MavenITmng6065FailOnSeverityTest.java
index e9b0eb9..b2f2ef8 100644
--- a/core-it-suite/src/test/java/org/apache/maven/it/MavenITmng6065LogFailLevelTest.java
+++ b/core-it-suite/src/test/java/org/apache/maven/it/MavenITmng6065FailOnSeverityTest.java
@@ -25,27 +25,28 @@ import java.io.File;
 
 /**
  * An integration test to verify that builds fail when logs occur
  * above or equal to the --fail-level cli property.
  *
  * <a href="https://issues.apache.org/jira/browse/MNG-6065">MNG-6065</a>.
  *
  */
-public class MavenITmng6065LogFailLevelTest
+public class MavenITmng6065FailOnSeverityTest
     extends AbstractMavenIntegrationTestCase
 {
 
-    public MavenITmng6065LogFailLevelTest()
+    public MavenITmng6065FailOnSeverityTest()
     {
-        super( "[3.6.3-SNAPSHOT,)" );
+        super( "[3.7.0-SNAPSHOT,)" );
     }
 
     public void testItShouldFailOnWarnLogMessages()
-        throws Exception
+            throws Exception
     {
-        File testDir = ResourceExtractor.simpleExtractResources( getClass(), "/mng-6065-log-fail-level" );
+        File testDir = ResourceExtractor.simpleExtractResources( getClass(), "/mng-6065-fail-on-severity" );
 
         Verifier verifier = newVerifier( testDir.getAbsolutePath(), false );
-        verifier.addCliOption( "--fail-level" );
+        verifier.setForkJvm( true );
+        verifier.addCliOption( "--fail-on-severity" );
         verifier.addCliOption( "WARN" );
 
         boolean failed = false;
@@ -67,10 +68,11 @@ public class MavenITmng6065LogFailLevelTest
     public void testItShouldSucceedOnWarnLogMessagesWhenFailLevelIsError()
             throws Exception
     {
-        File testDir = ResourceExtractor.simpleExtractResources( getClass(), "/mng-6065-log-fail-level" );
+        File testDir = ResourceExtractor.simpleExtractResources( getClass(), "/mng-6065-fail-on-severity" );
 
         Verifier verifier = newVerifier( testDir.getAbsolutePath(), false );
-        verifier.addCliOption( "--fail-level" );
+        verifier.setForkJvm( true );
+        verifier.addCliOption( "--fail-on-severity" );
         verifier.addCliOption( "ERROR" );
 
         verifier.executeGoal( "compile" );
@@ -25,27 +25,28 @@ import java.io.File;
 /**
  * An integration test to verify that builds fail when logs occur
- * above or equal to the --fail-level cli property.
+ * above or equal to the --fail-on-severity cli property.
  *
  * <a href="https://issues.apache.org/jira/browse/MNG-6065">MNG-6065</a>.